# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61oi_catalog.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\x85\x02\n\x08\x41OIStats\x12+\n\ncategories\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tcountries\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07sources\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06states\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05types\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe6\x01\n\x12\x41OIStatsGetRequest\x12\x0c\n\x04\x62\x62ox\x18\x01 \x03(\x01\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12\x10\n\x08min_area\x18\x08 \x01(\x01\x12\x10\n\x08max_area\x18\t \x01(\x01\x12\x0f\n\x07sources\x18\n \x03(\t\x12*\n\x0clibrary_type\x18\x0b \x01(\x0e\x32\x14.oi.papi.LibraryType\"P\n\x13\x41OIStatsGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\taoi_stats\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIStats\"6\n\nAOICluster\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0c\n\x04long\x18\x02 \x01(\x01\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xe8\x01\n\x14\x41OIClusterGetRequest\x12\x0c\n\x04\x62\x62ox\x18\x01 \x03(\x01\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12\x10\n\x08min_area\x18\x08 \x01(\x01\x12\x10\n\x08max_area\x18\t \x01(\x01\x12\x0f\n\x07sources\x18\n \x03(\t\x12*\n\x0clibrary_type\x18\x0b \x01(\x0e\x32\x14.oi.papi.LibraryType\"W\n\x15\x41OIClusterGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x61oi_clusters\x18\x02 \x03(\x0b\x32\x13.oi.papi.AOICluster\"\'\n\x14\x41OICatalogAddRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\",\n\x15\x41OICatalogAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"*\n\x17\x41OICatalogDeleteRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\"/\n\x18\x41OICatalogDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r*&\n\x0bLibraryType\x12\x0b\n\x07PRIVATE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x32\xe3\x02\n\rAOICatalogApi\x12J\n\rget_aoi_stats\x12\x1b.oi.papi.AOIStatsGetRequest\x1a\x1c.oi.papi.AOIStatsGetResponse\x12Q\n\x10get_aoi_clusters\x12\x1d.oi.papi.AOIClusterGetRequest\x1a\x1e.oi.papi.AOIClusterGetResponse\x12S\n\x12\x61\x64\x64_aoi_to_catalog\x12\x1d.oi.papi.AOICatalogAddRequest\x1a\x1e.oi.papi.AOICatalogAddResponse\x12^\n\x17\x64\x65lete_aoi_from_catalog\x12 .oi.papi.AOICatalogDeleteRequest\x1a!.oi.papi.AOICatalogDeleteResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_catalog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LIBRARYTYPE']._serialized_start=1220
  _globals['_LIBRARYTYPE']._serialized_end=1258
  _globals['_AOISTATS']._serialized_start=82
  _globals['_AOISTATS']._serialized_end=343
  _globals['_AOISTATSGETREQUEST']._serialized_start=346
  _globals['_AOISTATSGETREQUEST']._serialized_end=576
  _globals['_AOISTATSGETRESPONSE']._serialized_start=578
  _globals['_AOISTATSGETRESPONSE']._serialized_end=658
  _globals['_AOICLUSTER']._serialized_start=660
  _globals['_AOICLUSTER']._serialized_end=714
  _globals['_AOICLUSTERGETREQUEST']._serialized_start=717
  _globals['_AOICLUSTERGETREQUEST']._serialized_end=949
  _globals['_AOICLUSTERGETRESPONSE']._serialized_start=951
  _globals['_AOICLUSTERGETRESPONSE']._serialized_end=1038
  _globals['_AOICATALOGADDREQUEST']._serialized_start=1040
  _globals['_AOICATALOGADDREQUEST']._serialized_end=1079
  _globals['_AOICATALOGADDRESPONSE']._serialized_start=1081
  _globals['_AOICATALOGADDRESPONSE']._serialized_end=1125
  _globals['_AOICATALOGDELETEREQUEST']._serialized_start=1127
  _globals['_AOICATALOGDELETEREQUEST']._serialized_end=1169
  _globals['_AOICATALOGDELETERESPONSE']._serialized_start=1171
  _globals['_AOICATALOGDELETERESPONSE']._serialized_end=1218
  _globals['_AOICATALOGAPI']._serialized_start=1261
  _globals['_AOICATALOGAPI']._serialized_end=1616
# @@protoc_insertion_point(module_scope)
